from calculator import NoraCalculator

num_a, num_b = 10, 20

test = NoraCalculator(num_a, num_b)

def test_sum():    
    assert(test.norasum() == 30)

def test_subtract():    
    assert(test.norasubtract() == -10)
    
def test_multiply():    
    assert(test.noramultiply() == 200)
    
def test_division():    
    assert(test.noradivision() == 0.5)


from setuptools import setup

setup(
    name="NoraCalculator",
    version="0.0.1",
    author="Wellington Nora",
    author_email="wellington_nora94@hotmail.com",
    url="https://github.com/wjnnora/SamplePyPi",
    description="An example package PyPi using math functions.",
    packages=["NoraCalculator"],
    zip_safe=False
)


class NoraCalculator:
    """Class for basic math operations"""
    
    def __init__(self, num_a, num_b):
        self.num_a = num_a
        self.num_b = num_b
    
    def norasum(self):
        """
        Calculate the sum of two numbers.
        Args:
            None.
        Return:
            float: the sum of two numbers.        
        """        
        return self.num_a + self.num_b
    
    def norasubtract(self):
        """
        Calculate the subtract of two numbers.
        Args:
            None.
        Return:
            float: the subtract of two numbers.            
        """    
        return self.num_a - self.num_b
    
    def noramultiply(self):
        """
        Calculate the multiply of two numbers.
        Args:
            None.
        Return:
            float: the multiply of two numbers.            
        """    
        return self.num_a * self.num_b
    
    def noradivision(self, num_round=2):
        """
        Calculate the division of two numbers.
        Args:
            num_round (int): the numb of places after comma that function must to return. 
        Return:
            float: the sum of two numbers.            
        """    
        return round(self.num_a / self.num_b, num_round)